@@ -85,8 +85,8 @@ def get_config_file_or_fail(app_name: str) -> Path:
         if Path(env_var_file).exists():
             log.debug(f'File "{env_var_file}" exists.')
             return Path(env_var_file)
-        else:
-            log.debug(f'File "{env_var_file}" does not exist. Skipping it.')
+        # else:
+        log.debug(f'File "{env_var_file}" does not exist. Skipping it.')
     else:
         log.debug(
             f'Env var "{env_var}" not set. '
@@ -132,7 +132,7 @@ def get_config_file_or_fail(app_name: str) -> Path:
         return valid_conf_files[0]
     # handle failure
     raise Exception(
-        f"Could not find a valid config file for app_name {app_name}. "
+        f"Could not find a valid config file for `app_name` {app_name}. "
         f"Searched for files {config_file_names} in folders {site_conf} "
         f"and {user_conf}, found nothing"
     )
@@ -189,7 +189,7 @@ def get_config_obj_or_fail(app_name: str) -> Dict[str, Any]:
         obj = dict(toml.loads(conf_file.read_text()))  # type: ignore
     else:
         raise Exception(
-            f"Found config file {conf_file}. get_config_key "
+            f"Found config file {conf_file}. `get_config_key` "
             f"does not support config files of type {conf_file.suffix}. "
             "Only .toml, .ini and .json files are supported"
         )
@@ -275,22 +275,43 @@ def get_cache_dir(app_name: str) -> Path:
     create and return a cache dir for cache data.
     prefer system-wide data dir, fall back to user cache dir
     """
-    env_var_file = os.environ.get(f"{app_name.upper()}_CACHE_PATH")
-    if env_var_file:
+    env_var_path = os.environ.get(f"{app_name.upper()}_CACHE_PATH")
+    site_cache_env_var = "SI_UTILS_SITE_CACHE"
+    user_cache_env_var = "SI_UTILS_USER_CACHE"
+    if env_var_path:
         try:
-            path = Path(env_var_file)
+            path = Path(env_var_path)
             path.mkdir(parents=True, exist_ok=True)
             return path
         except OSError:
             pass
-    system_cache_dir = Path(AppDirs("si-utils").site_data_dir)
+
+    system_cache_dir: Path
+    system_cache_dir = os.environ.get(site_cache_env_var)  # type: ignore
+    if system_cache_dir:
+        system_cache_dir = Path(system_cache_dir)
+        log.debug(
+            f"Env var {site_cache_env_var} is set. "
+            "Adding it to the config file search path"
+        )
+    else:
+        system_cache_dir = Path(AppDirs("si-utils").site_data_dir)
     system_cache_dir = system_cache_dir.joinpath(app_name)
     try:
         system_cache_dir.mkdir(parents=True, exist_ok=True)
         return system_cache_dir
     except OSError:
         pass
-    user_cache_dir = Path(AppDirs("si-utils").user_cache_dir)
+    user_cache_dir: Path
+    user_cache_dir = os.environ.get(user_cache_env_var)  # type: ignore
+    if user_cache_dir:
+        user_cache_dir = Path(user_cache_dir)
+        log.debug(
+            f"Env var {user_cache_env_var} is set. "
+            "Adding it to the config file search path"
+        )
+    else:
+        user_cache_dir = Path(AppDirs("si-utils").user_cache_dir)
     user_cache_dir = user_cache_dir.joinpath(app_name)
     try:
         user_cache_dir.mkdir(parents=True, exist_ok=True)
